==> react-molecule-field-1.13.0.tgz: package/lib/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import AtomValidationText, { AtomValidationTextTypes } from '@s-ui/react-atom-validation-text';
import AtomLabel, { AtomLabelTypes } from '@s-ui/react-atom-label';
import AtomHelpText from '@s-ui/react-atom-help-text';
var BASE_CLASS = 'sui-MoleculeField';
var CLASS_INLINE = BASE_CLASS + "--inline";
var CLASS_INLINE_REVERSE = CLASS_INLINE + "-reverse";
var CLASS_INPUT_CONTAINER = BASE_CLASS + "-inputContainer";
var CLASS_LABEL_CONTAINER = BASE_CLASS + "-labelContainer";

var MoleculeField = function MoleculeField(_ref) {
  var inline = _ref.inline,
      reverse = _ref.reverse,
      errorText = _ref.errorText,
      successText = _ref.successText,
      label = _ref.label,
      useContrastLabel = _ref.useContrastLabel,
      helpText = _ref.helpText,
      name = _ref.name,
      onClickLabel = _ref.onClickLabel,
      onChangeFromProps = _ref.onChange,
      children = _ref.children;
  var className = cx(BASE_CLASS, inline && CLASS_INLINE, inline && reverse && CLASS_INLINE_REVERSE);
  var statusValidationText, typeValidationLabel, typeValidationText;
  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index) {
    return React.cloneElement(child, {
      onChange: onChangeFromProps
    });
  });

  if (useContrastLabel) {
    typeValidationLabel = AtomLabelTypes.CONTRAST;
  }

  if (errorText) {
    statusValidationText = errorText;
    typeValidationLabel = AtomLabelTypes.ERROR;
    typeValidationText = AtomValidationTextTypes.ERROR;
  }

  if (successText) {
    statusValidationText = successText;
    typeValidationLabel = AtomLabelTypes.SUCCESS;
    typeValidationText = AtomValidationTextTypes.SUCCESS;
  }

  return React.createElement("div", {
    className: className
  }, label && React.createElement("div", {
    className: CLASS_LABEL_CONTAINER
  }, inline && extendedChildren, React.createElement(AtomLabel, {
    type: typeValidationLabel,
    name: name,
    text: label,
    onClick: onClickLabel
  })), React.createElement("div", {
    className: CLASS_INPUT_CONTAINER
  }, !inline && extendedChildren, (successText || errorText) && React.createElement(AtomValidationText, {
    type: typeValidationText,
    text: statusValidationText
  }), helpText && React.createElement(AtomHelpText, {
    text: helpText
  })));
};

MoleculeField.displayName = 'MoleculeField';
export default MoleculeField;

==> react-molecule-field-1.14.0.tgz: package/lib/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import AtomValidationText, { AtomValidationTextTypes } from '@s-ui/react-atom-validation-text';
import AtomLabel, { AtomLabelTypes } from '@s-ui/react-atom-label';
import AtomHelpText from '@s-ui/react-atom-help-text';
var BASE_CLASS = 'sui-MoleculeField';
var CLASS_INLINE = BASE_CLASS + "--inline";
var CLASS_INLINE_REVERSE = CLASS_INLINE + "-reverse";
var CLASS_INPUT_CONTAINER = BASE_CLASS + "-inputContainer";
var CLASS_LABEL_CONTAINER = BASE_CLASS + "-labelContainer";

var MoleculeField = function MoleculeField(_ref) {
  var inline = _ref.inline,
      reverse = _ref.reverse,
      errorText = _ref.errorText,
      successText = _ref.successText,
      alertText = _ref.alertText,
      label = _ref.label,
      useContrastLabel = _ref.useContrastLabel,
      helpText = _ref.helpText,
      name = _ref.name,
      onClickLabel = _ref.onClickLabel,
      onChangeFromProps = _ref.onChange,
      children = _ref.children;
  var className = cx(BASE_CLASS, inline && CLASS_INLINE, inline && reverse && CLASS_INLINE_REVERSE);
  var statusValidationText, typeValidationLabel, typeValidationText;
  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index) {
    return React.cloneElement(child, {
      onChange: onChangeFromProps
    });
  });

  if (useContrastLabel) {
    typeValidationLabel = AtomLabelTypes.CONTRAST;
  }

  if (errorText) {
    statusValidationText = errorText;
    typeValidationLabel = AtomLabelTypes.ERROR;
    typeValidationText = AtomValidationTextTypes.ERROR;
  }

  if (successText) {
    statusValidationText = successText;
    typeValidationLabel = AtomLabelTypes.SUCCESS;
    typeValidationText = AtomValidationTextTypes.SUCCESS;
  }

  if (alertText) {
    statusValidationText = alertText;
    typeValidationLabel = AtomLabelTypes.ALERT;
    typeValidationText = AtomValidationTextTypes.ALERT;
  }

  return React.createElement("div", {
    className: className
  }, label && React.createElement("div", {
    className: CLASS_LABEL_CONTAINER
  }, inline && extendedChildren, React.createElement(AtomLabel, {
    type: typeValidationLabel,
    name: name,
    text: label,
    onClick: onClickLabel
  })), React.createElement("div", {
    className: CLASS_INPUT_CONTAINER
  }, !inline && extendedChildren, typeValidationText && React.createElement(AtomValidationText, {
    type: typeValidationText,
    text: statusValidationText
  }), helpText && React.createElement(AtomHelpText, {
    text: helpText
  })));
};

MoleculeField.displayName = 'MoleculeField';
export default MoleculeField;
